<?php
namespace NicolasBejean\CategoryWidget\Block\Adminhtml\CategoryWidget;

use \Magento\Backend\Block\Template;
use \Magento\Backend\Block\Template\Context;
use \Magento\Framework\Exception\LocalizedException;
use \Magento\Framework\Exception\NoSuchEntityException;
use \Magento\Framework\Serialize\Serializer\Json as JsonSerializer;

use \NicolasBejean\CategoryWidget\Model\CategoryWidget as CategoryWidgetModel;
use \NicolasBejean\CategoryWidget\Model\CategoryWidgetRepository;

use \Magento\Catalog\Model\Category as CategoryModel;
use \Magento\Catalog\Model\ResourceModel\Category\Collection;
use \Magento\Catalog\Model\ResourceModel\Category\CollectionFactory;
use \Magento\Catalog\Model\CategoryRepository;

use \Exception;

/**
 * Class AssignCategories
 *
 * @category PHP
 * @package  NicolasBejean\CategoryWidget\Block\Adminhtml\CategoryWidget
 * @author   Nicolas Béjean <nicolas@bejean.eu>
 * @license  https://github.com/nicolasbejean/category-widget/blob/master/licence.txt BSD Licence
 * @link     https://www.bejean.eu
 */
class AssignCategories extends Template
{
    /**
     * Block template
     *
     * @var string
     */
    protected $_template = 'NicolasBejean_CategoryWidget::categorywidget/edit/assign_categories.phtml';

    /**
     * @var JsonSerializer
     */
    private $jsonSerializer;

    /**
     * @var CollectionFactory
     */
    private $collectionFactory;

    /**
     * @var CategoryRepository
     */
    private $categoryRepository;

    /**
     * @var CategoryWidgetRepository
     */
    private $categoryWidgetRepository;

    /**
     * AssignImages constructor.
     *
     * @param Context $context
     * @param JsonSerializer $jsonSerializer
     * @param CollectionFactory $collectionFactory
     * @param CategoryRepository $categoryRepository
     * @param CategoryWidgetRepository $categoryWidgetRepository
     * @param array $data
     */
    public function __construct
    (
        Context                             $context,
        JsonSerializer                      $jsonSerializer,
        CollectionFactory                   $collectionFactory,
        CategoryRepository                  $categoryRepository,
        CategoryWidgetRepository            $categoryWidgetRepository,
        array $data                         = []
    )
    {
        $this->jsonSerializer               = $jsonSerializer;
        $this->collectionFactory            = $collectionFactory;

        $this->categoryRepository           = $categoryRepository;
        $this->categoryWidgetRepository     = $categoryWidgetRepository;

        parent::__construct($context, $data);
    }

    /**
     * @return array
     */
    public function getCollection()
    {
        try {
            /** @var Collection $collection */
            $collection = $this->collectionFactory->create()
                ->addAttributeToFilter('level', array('nin' => array(0,1)))
                ->toOptionArray();

            if (!empty($collection)) {
                $result = array();

                foreach ($collection as $item) {
                    array_push($result, $this->getCategory($item['value']));
                }

                return $result;
            }
        } catch (Exception $e) {
            return array($e->getMessage());
        }

        return array();
    }

    /**
     * @param $id
     * @return array
     * @throws NoSuchEntityException
     * @throws LocalizedException
     */
    private function getCategory (int $id)
    {
        /** @var CategoryModel $category */
        $category = $this->categoryRepository->get($id);

        $result = array();
        $result['id'] = $category->getId();
        $result['is_active'] = $category->getIsActive();
        $result['name'] = $category->getName();
        $result['image_path'] = $category->getImageUrl('image');
        $result['description'] = $category->getCustomAttribute('description');
        $result['url'] = $category->getUrlKey();

        return $result;
    }

    /**
     * Get Selected Item
     *
     * @param int $id
     * @return array
     * @throws LocalizedException
     * @throws NoSuchEntityException
     */
    public function getSelectedItem (int $id)
    {
        /** @var CategoryWidgetModel $categoryWidget */
        $categoryWidget = $this->categoryWidgetRepository->getById($id);

        $array = explode('|', $categoryWidget->getContent());
        $array = array_map('intval', $array);

        $result = array();

        foreach ($array as $itemId) {
            array_push($result, $this->getCategory((int)$itemId));
        }

        return $result;
    }
}
