<?php
namespace NicolasBejean\CategoryWidget\Block\Adminhtml\CategoryWidget\Edit;

use \Magento\Backend\Block\Widget\Context;
use \Magento\Framework\Exception\LocalizedException;
use \Magento\Framework\Exception\NoSuchEntityException;
use \NicolasBejean\CategoryWidget\Api\CategoryWidgetRepositoryInterface;

/**
 * Class GenericButton
 *
 * @category PHP
 * @package  NicolasBejean\CategoryWidget\Block\Adminhtml\CategoryWidget\Edit
 * @author   Nicolas Béjean <nicolas@bejean.eu>
 * @license  https://github.com/nicolasbejean/category-widget/blob/master/licence.txt BSD Licence
 * @link     https://www.bejean.eu
 */
class GenericButton
{
    /**
     * @var Context
     */
    protected $context;

    /**
     * @var CategoryWidgetRepositoryInterface
     */
    protected $categoryWidgetRepository;

    /**
     * GenericButton constructor.
     * @param Context                           $context
     * @param CategoryWidgetRepositoryInterface    $categoryWidgetRepository
     */
    public function __construct(
        Context                                 $context,
        CategoryWidgetRepositoryInterface       $categoryWidgetRepository
    ) {
        $this->context                          = $context;
        $this->categoryWidgetRepository         = $categoryWidgetRepository;
    }

    /**
     * Get Category Widget ID
     *
     * @return int|null
     * @throws LocalizedException
     */
    public function getCategoryWidgetId()
    {
        try {
            return $this->categoryWidgetRepository->getById(
                $this->context->getRequest()->getParam('entity_id')
            )->getId();
        } catch (NoSuchEntityException $e) {
        } catch (LocalizedException $e) {
            throw new LocalizedException(__('Category Widget with id "%1" does not exist.'));
        }
        return null;
    }

    /**
     * Get URL by route and parameters
     *
     * @param string $route
     * @param array  $params
     * @return string
     */
    public function getUrl($route = '', $params = [])
    {
        return $this->context->getUrlBuilder()->getUrl($route, $params);
    }
}
