<?php
namespace NicolasBejean\CategoryWidget\Controller\Adminhtml\CategoryWidget;

use \Magento\Backend\App\Action\Context;
use \Magento\Backend\Model\View\Result\Page;
use \Magento\Backend\Model\View\Result\Redirect;
use \Magento\Framework\Controller\ResultInterface;
use \Magento\Framework\Registry;
use \Magento\Framework\View\Result\PageFactory;
use \NicolasBejean\CategoryWidget\Controller\Adminhtml\CategoryWidget;
use \NicolasBejean\CategoryWidget\Model\CategoryWidget as CategoryWidgetModel;

/**
 * Class Edit
 *
 * @category PHP
 * @package  NicolasBejean\CategoryWidget\Controller\Adminhtml\CategoryWidget
 * @author   Nicolas Béjean <nicolas@bejean.eu>
 * @license  https://github.com/nicolasbejean/category-widget/blob/master/licence.txt BSD Licence
 * @link     https://www.bejean.eu
 */
class Edit extends CategoryWidget
{
    /**
     * @var PageFactory
     */
    protected $resultPageFactory;

    /**
     * @param Context               $context
     * @param Registry              $coreRegistry
     * @param PageFactory           $resultPageFactory
     */
    public function __construct(
        Context                     $context,
        Registry                    $coreRegistry,
        PageFactory                 $resultPageFactory
    ) {
        $this->resultPageFactory    = $resultPageFactory;

        parent::__construct($context, $coreRegistry);
    }

    /**
     * Edit category widget
     *
     * @return ResultInterface
     * @SuppressWarnings(PHPMD.NPathComplexity)
     */
    public function execute()
    {
        // 1. Get ID and create model
        $id = $this->getRequest()->getParam('entity_id');
        /** @var CategoryWidgetModel $model */
        $model = $this->_objectManager->create(CategoryWidgetModel::class);

        // 2. Initial checking
        if ($id) {
            $model->load($id);
            if (!$model->getId()) {
                $this->messageManager->addErrorMessage(__('This category widget no longer exists.'));
                /** @var Redirect $resultRedirect */
                $resultRedirect = $this->resultRedirectFactory->create();
                return $resultRedirect->setPath('*/*/');
            }
        }

        $this->coreRegistry->register('nicolasbejean_categorywidget_item', $model);

        // 5. Build edit form
        /** @var Page $resultPage */
        $resultPage = $this->resultPageFactory->create();
        $this->initPage($resultPage)->addBreadcrumb(
            $id ? __('Edit Category Widget') : __('New Category Widget'),
            $id ? __('Edit Category Widget') : __('New Category Widget')
        );
        $resultPage->getConfig()->getTitle()->prepend(__('Category Widget'));
        $resultPage->getConfig()->getTitle()->prepend($model->getId() ? $model->getName() . ' (' . $model->getIdentifier() . ')' : __('New Category Widget'));
        return $resultPage;
    }
}
